@@ -3,7 +3,7 @@ from __future__ import (unicode_literals, absolute_import)
 
 from django import forms
 from django.core.exceptions import ValidationError
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy as _
 from . import VATIN, VIES_COUNTRY_CHOICES
 from .widgets import VATINWidget, VATINHiddenWidget
 
